@@ -1,23 +1,26 @@
-(defproject cheshire "5.3.1"
+(defproject cheshire "5.4.0"
   :description "JSON and JSON SMILE encoding, fast."
   :url "https://github.com/dakrone/cheshire"
   :license {:name "The MIT License"
             :url "http://opensource.org/licenses/MIT"
             :distribution :repo}
   :warn-on-reflection false
-  :dependencies [[com.fasterxml.jackson.core/jackson-core "2.3.1"]
-                 [com.fasterxml.jackson.dataformat/jackson-dataformat-smile "2.3.1"]
+  :dependencies [[com.fasterxml.jackson.core/jackson-core "2.4.4"]
+                 [com.fasterxml.jackson.dataformat/jackson-dataformat-smile "2.4.4"]
+                 [com.fasterxml.jackson.dataformat/jackson-dataformat-cbor "2.4.4"]
                  [tigris "0.1.1"]]
-  :profiles {:dev {:dependencies [[org.clojure/clojure "1.5.1"]
+  :profiles {:dev {:dependencies [[org.clojure/clojure "1.6.0"]
                                   [org.clojure/test.generative "0.1.4"]]}
              :1.2 {:dependencies [[org.clojure/clojure "1.2.1"]]}
              :1.3 {:dependencies [[org.clojure/clojure "1.3.0"]]}
              :1.4 {:dependencies [[org.clojure/clojure "1.4.0"]]}
+             :1.5 {:dependencies [[org.clojure/clojure "1.5.1"]]}
+             :1.7 {:dependencies [[org.clojure/clojure "1.7.0-alpha4"]]}
              :benchmark {:test-paths ["benchmarks"]
-                         :dependencies [[criterium "0.4.2"]
-                                        [org.clojure/data.json "0.2.3"]
+                         :dependencies [[criterium "0.4.3"]
+                                        [org.clojure/data.json "0.2.5"]
                                         [clj-json "0.5.3"]]}}
-  :aliases {"all" ["with-profile" "dev,1.3:dev,1.4:dev"]
+  :aliases {"all" ["with-profile" "dev,1.3:dev,1.4:dev,1.5:dev,1.7:dev"]
             "benchmark" ["with-profile" "dev,benchmark" "test"]
             "core-bench" ["with-profile" "dev,benchmark" "test" ":only"
                           "cheshire.test.benchmark/t-bench-core"]}
