@@ -1,12 +1,14 @@
-(defproject clj-tuple "0.1.2"
+(defproject clj-tuple "0.1.5"
   :description "Efficient small collections."
   :license {:name "MIT License"
             :url "http://opensource.org/licenses/MIT"}
   :dependencies []
-  :profiles {:dev {:dependencies [[org.clojure/clojure "1.5.1"]
+  :profiles {:dev {:dependencies [[org.clojure/clojure "1.6.0"]
                                   [criterium "0.4.1"]
-                                  [reiddraper/simple-check "0.2.1"]]}}
+                                  [collection-check "0.1.3"]]}
+             :1.5 {:dependencies [[org.clojure/clojure "1.5.1"]]}}
   :global-vars {*warn-on-reflection* true}
   :test-selectors {:benchmark :benchmark
-                   :default (complement :benchmark)}
+                   :stress :stress
+                   :default #(every? (complement #{:benchmark :stress}) (keys %))}
   :jvm-opts ^:replace ["-server" "-Xmx500m" "-XX:NewSize=200m"])
