@@ -1,4 +1,5 @@
 (ns ring.middleware.multipart-params.temp-file
+  "A multipart storage engine for storing uploads in temporary files."
   (:require [clojure.java.io :as io])
   (:import java.io.File))
 
@@ -39,14 +40,18 @@
 (defn temp-file-store
   "Returns a function that stores multipart file parameters as temporary files.
   Accepts the following options:
-    :expires-in - delete temporary files older than this many seconds
-                  (defaults to 3600 - 1 hour)
+
+  :expires-in - delete temporary files older than this many seconds
+                (defaults to 3600 - 1 hour)
+
   The multipart parameters will be stored as maps with the following keys:
-    :filename     - the name of the uploaded file
-    :content-type - the content type of the upload file
-    :tempfile     - a File object that points to the temporary file containing
-                    the uploaded data.
-    :size         - the size in bytes of the uploaded data"
+
+  :filename     - the name of the uploaded file
+  :content-type - the content type of the upload file
+  :tempfile     - a File object that points to the temporary file containing
+                  the uploaded data
+  :size         - the size in bytes of the uploaded data"
+  {:arglists '([] [options])}
   ([] (temp-file-store {:expires-in 3600}))
   ([{:keys [expires-in]}]
      (let [file-set (atom #{})
