@@ -2,41 +2,34 @@
   (:import [java.security KeyStore])
   (:require [me.raynes.fs :as fs]
             [clj-http.client :as client]
+            [puppetlabs.http.client.sync :as pl-http]
             [puppetlabs.puppetdb.admin :as admin]
             [puppetlabs.trapperkeeper.testutils.logging :refer [with-log-output logs-matching]]
             [puppetlabs.puppetdb.cli.services :refer :all]
-            [puppetlabs.puppetdb.http.command :refer :all]
+            [puppetlabs.puppetdb.testutils.cli :refer [get-factsets]]
+            [puppetlabs.puppetdb.command :refer [enqueue-command]]
             [puppetlabs.puppetdb.utils :as utils]
             [puppetlabs.puppetdb.scf.storage-utils :as sutils]
             [puppetlabs.puppetdb.meta.version :as version]
             [clojure.test :refer :all]
             [puppetlabs.puppetdb.testutils.services :as svc-utils :refer [*base-url*]]
             [puppetlabs.trapperkeeper.app :refer [get-service]]
-            [puppetlabs.puppetdb.testutils :refer [block-until-results]]
+            [puppetlabs.puppetdb.testutils :refer [block-until-results temp-file]]
             [clj-time.coerce :refer [to-string]]
-            [clj-time.core :refer [now]]
-            [puppetlabs.puppetdb.cli.export :as export]))
+            [clj-time.core :refer [now]]))
 
 (deftest update-checking
-  (testing "should check for updates if running as puppetdb"
-    (with-redefs [version/check-for-updates! (constantly "Checked for updates!")]
-      (is (= (maybe-check-for-updates "puppetdb" "update-server!" {}) "Checked for updates!"))))
+  (let [config-map {:global {:product-name "puppetdb"
+                              :update-server "update-server!"}}]
 
-  (testing "should skip the update check if running as pe-puppetdb"
-    (with-log-output log-output
-      (maybe-check-for-updates "pe-puppetdb" "update-server!" {})
-      (is (= 1 (count (logs-matching #"Skipping update check on Puppet Enterprise" @log-output)))))))
+    (testing "should check for updates if running as puppetdb"
+      (with-redefs [version/check-for-updates! (constantly "Checked for updates!")]
+        (is (= (maybe-check-for-updates config-map {}) "Checked for updates!"))))
 
-(deftest whitelisting
-  (testing "should log on reject"
-    (let [wl (fs/temp-file "whitelist-log-reject")]
-      (.deleteOnExit wl)
-      (spit wl "foobar")
-      (let [f (build-whitelist-authorizer (fs/absolute-path wl))]
-        (is (= :authorized (f {:ssl-client-cn "foobar"})))
-        (with-log-output logz
-          (is (string? (f {:ssl-client-cn "badguy"})))
-          (is (= 1 (count (logs-matching #"^badguy rejected by certificate whitelist " @logz)))))))))
+    (testing "should skip the update check if running as pe-puppetdb"
+      (with-log-output log-output
+        (maybe-check-for-updates (assoc-in config-map [:global :product-name] "pe-puppetdb") {})
+        (is (= 1 (count (logs-matching #"Skipping update check on Puppet Enterprise" @log-output))))))))
 
 (defn- check-service-query
   [endpoint version q pagination check-result]
@@ -58,16 +51,17 @@
 
 (deftest query-via-puppdbserver-service
   (svc-utils/with-single-quiet-pdb-instance
-    (let [pdb-cmd-service (get-service svc-utils/*server* :PuppetDBCommand)
+    (let [dispatcher (get-service svc-utils/*server* :PuppetDBCommandDispatcher)
           query-fn (partial query (get-service svc-utils/*server* :PuppetDBServer))]
-      (submit-command pdb-cmd-service :replace-facts 4 {:certname "foo.local"
-                                                        :environment "DEV"
-                                                        :values {:foo "the foo"
-                                                                 :bar "the bar"
-                                                                 :baz "the baz"}
-                                                        :producer_timestamp (to-string (now))})
+      (enqueue-command dispatcher :replace-facts 4
+                       {:certname "foo.local"
+                        :environment "DEV"
+                        :values {:foo "the foo"
+                                 :bar "the bar"
+                                 :baz "the baz"}
+                        :producer_timestamp (to-string (now))})
 
-      @(block-until-results 100 (export/facts-for-node query-fn "foo.local"))
+      @(block-until-results 100 (first (get-factsets "foo.local")))
 
       (check-service-query
        :facts :v4 ["=" "certname" "foo.local"]
@@ -89,14 +83,15 @@
 
 (deftest pagination-via-puppdbserver-service
   (svc-utils/with-puppetdb-instance
-    (let [pdb-cmd-service (get-service svc-utils/*server* :PuppetDBCommand)
+    (let [dispatcher (get-service svc-utils/*server* :PuppetDBCommandDispatcher)
           query-fn (partial query (get-service svc-utils/*server* :PuppetDBServer))]
-      (submit-command pdb-cmd-service :replace-facts 4 {:certname "foo.local"
-                                                    :environment "DEV"
-                                                    :values {:a "a" :b "b" :c "c"}
-                                                    :producer_timestamp (to-string (now))})
+      (enqueue-command dispatcher :replace-facts 4
+                       {:certname "foo.local"
+                        :environment "DEV"
+                        :values {:a "a" :b "b" :c "c"}
+                        :producer_timestamp (to-string (now))})
 
-      @(block-until-results 100 (export/facts-for-node query-fn "foo.local"))
+      @(block-until-results 100 (first (get-factsets "foo.local")))
       (let [exp ["a" "b" "c"]
             rexp (reverse exp)]
         (doseq [order [:ascending :descending]
@@ -133,3 +128,35 @@
         (testing (format "%s requests are refused" (name v)))
         (is (retirement-response? v (ping v)))))))
 
+(defn make-https-request-with-whitelisted-host [whitelisted-host]
+  (let [whitelist-file (temp-file "whitelist-log-reject")
+        cert-config {:ssl-cert "test-resources/localhost.pem"
+                     :ssl-key "test-resources/localhost.key"
+                     :ssl-ca-cert "test-resources/ca.pem"}
+        config (-> (svc-utils/create-config)
+                   (assoc :jetty (merge cert-config
+                                        {:ssl-port 0
+                                         :ssl-host "0.0.0.0"
+                                         :ssl-protocols "TLSv1,TLSv1.1"}))
+                   (assoc-in [:puppetdb :certificate-whitelist] (str whitelist-file)))]
+    (spit whitelist-file whitelisted-host)
+
+    (svc-utils/call-with-puppetdb-instance
+     config
+     (fn []
+       (pl-http/get (str (utils/base-url->str (assoc *base-url* :version :v4))
+                         "/facts")
+                    (merge cert-config
+                           {:headers {"accept" "application/json"}
+                            :as :text}))))))
+
+(deftest cert-whitelists
+  (testing "hosts not in whitelist should be forbidden"
+    (let [response (make-https-request-with-whitelisted-host "bogus")]
+      (is (= 403 (:status response)))
+      (is (re-find #"Permission denied" (:body response)))))
+
+  (testing "host in the cert whitelist is allowed"
+    (let [response (make-https-request-with-whitelisted-host "localhost")]
+      (is (= 200 (:status response)))
+      (is (not (re-find #"Permission denied" (:body response)))))))
