@@ -11,23 +11,13 @@
        nil "foo"
        nil "123foo"))
 
-(deftest test-unescape-string
-  (are [unescaped s] (= unescaped (unescape-string s))
-
-       "foo" "\"foo\""
-       "foo" "foo"
-       "123" "123"
-       "123foo" "\"123foo\""))
-
 (deftest test-unencode-path-segment
   (are [path-segment s] (= path-segment (unencode-path-segment s))
-
-       "foo" "\"foo\""
-       "\"foo\"" "\"\"foo\"\""
+       "\"foo\"" "\"foo\""
+       "\"\"foo\"\"" "\"\"foo\"\""
        "foo" "foo"
-
        "123" "\"123\""
-       "123foo" "\"123foo\""
+       "\"123foo\"" "\"123foo\""
        1 "1"
        123 "123"))
 
